==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/base/ibgwidgetbuttonsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Generic button
//
#ifndef IBGWIDGETBUTTONSUBJECT_H
#define IBGWIDGETBUTTONSUBJECT_H


#include "ibgwidgetsubject.h"


class iImage;
class iString;


class ibgWidgetButtonSubject : public ibgWidgetSubject
{

public:

	virtual ~ibgWidgetButtonSubject();

	//
	//  Decorator functions
	//
	virtual bool IsDown() const = 0;

	virtual void SetDown(bool s) = 0;
	virtual void SetIcon(const iImage &icon) = 0;
	virtual void SetText(const iString &text) = 0;

	virtual void SetAutoRepeat(bool s) = 0;

	virtual void SetSize(int w, int h) = 0;
	virtual void SetFlat(bool s) = 0;

protected:

	ibgWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot);

	int mType;
};

#endif  // IBGWIDGETBUTTONSUBJECT_H

==> ifrit_4.1.2.orig.tar.gz: ifrit-4.1.2/shells/base/ibgwidgetbuttonsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  Generic button
//
#ifndef IBGWIDGETBUTTONSUBJECT_H
#define IBGWIDGETBUTTONSUBJECT_H


#include "ibgwidgetsubject.h"


class iImage;
class iString;


class ibgWidgetButtonSubject : public ibgWidgetSubject
{

public:

	virtual ~ibgWidgetButtonSubject();

	//
	//  Decorator functions
	//
	virtual bool IsDown() const = 0;

	virtual void SetDown(bool s) = 0;
	virtual void SetIcon(const iImage &icon) = 0;
	virtual void SetText(const iString &text) = 0;

	virtual void SetAutoRepeat(bool s) = 0;

	virtual void SetSize(int w, int h) = 0;
	virtual void SetFlat(bool s) = 0;

protected:

	ibgWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot, int minsize);

	int mType;
};

#endif  // IBGWIDGETBUTTONSUBJECT_H
